@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the gzip program."""
+
 from . import extract_singlefile_standard, test_singlefile_standard
 from .. import util, fileutil, log
 import os
@@ -21,19 +21,26 @@ import subprocess
 
 test_gzip = test_compress = test_singlefile_standard
 
+
 def extract_gzip(archive, compression, cmd, verbosity, interactive, outdir):
+    """Extract given gzip archive."""
     cmdlist = [util.shell_quote(cmd)]
     if verbosity > 1:
         cmdlist.append('-v')
     outfile = get_original_filename(cmd, outdir, archive)
-    cmdlist.extend(['-c', '-d', '--', util.shell_quote(archive), '>',
-        util.shell_quote(outfile)])
+    cmdlist.extend(
+        ['-c', '-d', '--', util.shell_quote(archive), '>', util.shell_quote(outfile)]
+    )
     return (cmdlist, {'shell': True})
 
+
 extract_compress = extract_singlefile_standard
 
 
 def get_original_filename(cmd, outdir, archive):
+    """Get the original filename inside a gzip archive.
+    This parses the output of gzip --name --list.
+    """
     outfile = fileutil.get_single_outfile(outdir, archive)
     cmdlist = [cmd, "--name", "--list", archive]
     try:
@@ -63,7 +70,7 @@ def create_gzip(archive, compression, cmd, verbosity, interactive, filenames):
     return (cmdlist, {'shell': True})
 
 
-def list_gzip (archive, compression, cmd, verbosity, interactive):
+def list_gzip(archive, compression, cmd, verbosity, interactive):
     """List a GZIP archive."""
     cmdlist = [cmd]
     if verbosity > 0:
