@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,12 +14,15 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the unalz program."""
 
+
 def _maybe_add_password(cmdlist, password):
     if password:
         cmdlist.extend(['-pwd', password])
 
 
-def extract_alzip (archive, compression, cmd, verbosity, interactive, outdir, password=None):
+def extract_alzip(
+    archive, compression, cmd, verbosity, interactive, outdir, password=None
+):
     """Extract a ALZIP archive."""
     cmdlist = [cmd, '-d', outdir]
     _maybe_add_password(cmdlist, password)
@@ -28,11 +30,12 @@ def extract_alzip (archive, compression, cmd, verbosity, interactive, outdir, pa
     return cmdlist
 
 
-def list_alzip (archive, compression, cmd, verbosity, interactive, password=None):
+def list_alzip(archive, compression, cmd, verbosity, interactive, password=None):
     """List a ALZIP archive."""
     cmdlist = [cmd, '-l']
     _maybe_add_password(cmdlist, password)
     cmdlist.append(archive)
     return cmdlist
 
+
 test_alzip = list_alzip
