@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2011-2015 Bastian Kleineidam
+# Copyright (C) 2011-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the xdms program."""
+
 from .. import util
 
 
@@ -22,7 +22,9 @@ def _maybe_add_password(cmdlist, password):
         cmdlist.extend(['-p', password])
 
 
-def extract_dms (archive, compression, cmd, verbosity, interactive, outdir, password=None):
+def extract_dms(
+    archive, compression, cmd, verbosity, interactive, outdir, password=None
+):
     """Extract a DMS archive."""
     check_archive_ext(archive)
     cmdlist = [cmd, '-d', outdir]
@@ -33,7 +35,7 @@ def extract_dms (archive, compression, cmd, verbosity, interactive, outdir, pass
     return cmdlist
 
 
-def list_dms (archive, compression, cmd, verbosity, interactive, password=None):
+def list_dms(archive, compression, cmd, verbosity, interactive, password=None):
     """List a DMS archive."""
     check_archive_ext(archive)
     cmdlist = [cmd, 'v']
@@ -42,7 +44,7 @@ def list_dms (archive, compression, cmd, verbosity, interactive, password=None):
     return cmdlist
 
 
-def test_dms (archive, compression, cmd, verbosity, interactive, password=None):
+def test_dms(archive, compression, cmd, verbosity, interactive, password=None):
     """Test a DMS archive."""
     check_archive_ext(archive)
     cmdlist = [cmd, 't']
