@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2016 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,20 +12,26 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the 7z program"""
+
 from . import ArchiveTest, Content
 from .. import needs_program, needs_codec
 
+
 class Test7z(ArchiveTest):
+    """Test class for the 7z program"""
 
     program = '7z'
 
     @needs_program(program)
     def test_7z(self):
+        """Run archive commands with archives that 7z supports."""
         self.archive_commands('t .7z')
         self.archive_commands('t .cb7')
         self.archive_commands('t.zip')
         self.archive_commands('t.cbz')
         self.archive_commands('t.txt.xz', check=Content.Singlefile)
+        self.archive_commands('t.wim')
         self.archive_list('t.txt.gz')
         self.archive_list('t.txt.bz2')
         self.archive_list('t.txt.lzma')
@@ -39,6 +44,7 @@ class Test7z(ArchiveTest):
         self.archive_list('t.rpm')
         self.archive_list('t.deb')
         self.archive_list('t.iso')
+        self.archive_list('t.udf')
         self.archive_list('t.vhd')
         self.archive_extract('t.txt.gz', check=Content.Singlefile)
         self.archive_extract('t.txt.bz2', check=Content.Singlefile)
@@ -52,6 +58,7 @@ class Test7z(ArchiveTest):
         self.archive_extract('t.rpm', check=None)
         self.archive_extract('t.deb', check=None)
         self.archive_extract('t.iso')
+        self.archive_extract('t.udf')
         self.archive_extract('t.vhd', check=None)
         self.archive_test('t.txt.gz')
         self.archive_test('t.txt.bz2')
@@ -65,12 +72,14 @@ class Test7z(ArchiveTest):
         self.archive_test('t.rpm')
         self.archive_test('t.deb')
         self.archive_test('t.iso')
+        self.archive_test('t.udf')
         self.archive_test('t.vhd')
         self.archive_create('t.txt.gz', check=Content.Singlefile)
         self.archive_create('t.txt.bz2', check=Content.Singlefile)
 
     @needs_codec(program, 'rar')
     def test_7z_rar(self):
+        """Run archive commands with RAR archives."""
         # only succeeds with the rar module for 7z installed
         self.archive_list('t.rar')
         self.archive_extract('t.rar')
@@ -79,11 +88,16 @@ class Test7z(ArchiveTest):
     @needs_program('file')
     @needs_program(program)
     def test_7z_file(self):
+        """Run archive commands with renamed archives that 7z supports."""
         self.archive_commands('t.7z.foo', skip_create=True)
+        self.archive_commands('t.7z.001', skip_create=True)
         self.archive_commands('t.cb7.foo', skip_create=True)
         self.archive_commands('t.zip.foo', skip_create=True)
         self.archive_commands('t.cbz.foo', skip_create=True)
-        self.archive_commands('t.txt.xz.foo', skip_create=True, check=Content.Singlefile)
+        self.archive_commands(
+            't.txt.xz.foo', skip_create=True, check=Content.Singlefile
+        )
+        self.archive_commands('t.wim.foo', skip_create=True)
         self.archive_list('t.txt.gz.foo')
         self.archive_list('t.txt.bz2.foo')
         self.archive_list('t.jar.foo')
@@ -121,6 +135,7 @@ class Test7z(ArchiveTest):
     @needs_program('file')
     @needs_codec(program, 'rar')
     def test_7z_rar_file(self):
+        """Run archive commands with renamed RAR archives."""
         # only succeeds with the rar module for 7z installed
         self.archive_list(self.filename + '.rar.foo')
         self.archive_extract(self.filename + '.rar.foo')
@@ -128,18 +143,21 @@ class Test7z(ArchiveTest):
 
 
 class Test7zPassword(ArchiveTest):
+    """Test class for the 7z program with password protected archives"""
 
     program = '7z'
     password = 'thereisnotry'
 
     @needs_program(program)
     def test_7z(self):
+        """Run archive commands with password protected archives for 7z."""
         self.archive_commands('p .7z')
         self.archive_commands('p.zip')
         self.archive_commands('p.cbz')
 
     @needs_codec(program, 'rar')
     def test_7z_rar(self):
+        """Run archive commands with password protected RAR archives."""
         # only succeeds with the rar module for 7z installed
         self.archive_list('p.rar')
         self.archive_extract('p.rar')
@@ -148,6 +166,7 @@ class Test7zPassword(ArchiveTest):
     @needs_program('file')
     @needs_program(program)
     def test_7z_file(self):
+        """Run archive commands with renamed password protected archives for 7z."""
         self.archive_commands('p.7z.foo', skip_create=True)
         self.archive_commands('p.zip.foo', skip_create=True)
         self.archive_commands('p.cbz.foo', skip_create=True)
@@ -155,6 +174,7 @@ class Test7zPassword(ArchiveTest):
     @needs_program('file')
     @needs_codec(program, 'rar')
     def test_7z_rar_file(self):
+        """Run archive commands with renamed password protected RAR archives."""
         # only succeeds with the rar module for 7z installed
         self.archive_list('p.rar.foo')
         self.archive_extract('p.rar.foo')
