@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,20 +12,25 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the python bz2 module"""
+
 from . import ArchiveTest, Content
 from .. import needs_program
 
-class TestPybz2 (ArchiveTest):
+
+class TestPybz2(ArchiveTest):
+    """Test class for the python zipfile module"""
 
     program = 'py_bz2'
 
     @needs_program('bzip2')
-    def test_py_bz2 (self):
+    def test_py_bz2(self):
+        """Extract and create BZIP2 archives."""
         self.archive_extract('t.txt.bz2', check=Content.Singlefile)
         # bzip2 is used to test the created archive
         self.archive_create('t.txt.bz2', check=Content.Singlefile)
 
     @needs_program('file')
-    def test_py_bz2_file (self):
+    def test_py_bz2_file(self):
+        """Extract renamed BZIP2 archives."""
         self.archive_extract('t.txt.bz2.foo', check=Content.Singlefile)
-
