@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,27 +12,32 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the rpm program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestRpm (ArchiveTest):
+
+class TestRpm(ArchiveTest):
+    """Test class for the rpm program"""
 
     program = 'rpm'
 
     @needs_program(program)
     def test_rpm(self):
+        """List an RPM archive."""
         self.archive_list('t.rpm')
         # The rpm test fails on non-rpm system with missing dependencies.
         # I am too lazy to build a tiny rpm with one file
         # and no dependency.
-        #self.archive_test('t.rpm')
+        # self.archive_test('t.rpm')
 
     @needs_program('file')
     @needs_program(program)
     def test_rpm_file(self):
+        """List a renamed RPM archive."""
         self.archive_list('t.rpm.foo')
         # The rpm test fails on non-rpm system with missing dependencies.
         # I am too lazy to build a tiny rpm with one file
         # and no dependency.
-        #self.archive_test('t.rpm.foo')
-
+        # self.archive_test('t.rpm.foo')
