@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,15 +12,20 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the unadf program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestUnadf (ArchiveTest):
+
+class TestUnadf(ArchiveTest):
+    """Test class for the unadf program"""
 
     program = 'unadf'
 
     @needs_program(program)
     def test_unadf(self):
+        """Extract, list and test an ADF archive"""
         self.archive_extract('t.adf', check=None)
         self.archive_list('t.adf')
         self.archive_test('t.adf')
@@ -29,6 +33,7 @@ class TestUnadf (ArchiveTest):
     @needs_program('file')
     @needs_program(program)
     def test_unadf_file(self):
+        """Extract, list and test a renamed ADF archive"""
         self.archive_extract('t.adf.foo', check=None)
         self.archive_test('t.adf.foo')
         self.archive_list('t.adf.foo')
