@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2013-2015 Bastian Kleineidam
+# Copyright (C) 2013-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,15 +12,20 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test patool create command."""
+
 import unittest
 import os
 from patoolib import cli, fileutil
 from . import basedir, datadir, needs_program
 
+
 class ArchiveCreateTest(unittest.TestCase):
+    """Test class for patool create command."""
 
     @needs_program('7z')
     def test_create(self):
+        """Run cli function to create a 7Z archive."""
         tmpdir = fileutil.tmpdir(dir=basedir)
         try:
             files = [os.path.join(datadir, "t"), os.path.join(datadir, "t.txt")]
