@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2013-2015 Bastian Kleineidam
+# Copyright (C) 2013-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,6 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test patool search command"""
+
 import unittest
 import os
 from patoolib import cli
@@ -20,17 +21,25 @@ from . import datadir, needs_program
 
 
 class ArchiveSearchTest(unittest.TestCase):
+    """Test class for patool search command"""
 
     @needs_program('grep')
-    @needs_program('unzip')
     @needs_program('tar')
-    def test_search(self):
+    def test_search_tar(self):
+        """Run cli function to search in TAR archive."""
         pattern = "42"
         archive = os.path.join(datadir, "t.tar")
         self.search(pattern, archive)
+
+    @needs_program('grep')
+    @needs_program('unzip')
+    def test_search_zip(self):
+        """Run cli function to search in ZIP archive."""
+        pattern = "42"
         archive = os.path.join(datadir, "t.zip")
         self.search(pattern, archive)
 
     def search(self, pattern, archive):
+        """Utility function to run the cli search"""
         args = ["-vv", "--non-interactive", "search", pattern, archive]
         cli.main(args=args)
